@@ -1,5 +1,5 @@
 
-VERSION = '0.2'
+VERSION = '0.3'
 
 from .design_flute import Design_tapered_pflute, Design_straight_pflute, Design_tapered_folk_flute, Design_straight_folk_flute
 from .make_flute import Make_flute
@@ -8,6 +8,10 @@ from .make_cork import Make_cork
 from .design_shawm import Design_shawm, Design_folk_shawm
 from .make_shawm import Make_shawm
 from .make_mouthpiece import Make_mouthpiece
+from .make_bauble import Make_bauble
+
+from .design_whistle import Design_folk_whistle
+from .make_whistle import Make_whistle
 
 from .make_panpipe import Make_panpipe
 
@@ -25,11 +29,16 @@ def main():
             Make_flute,
             Make_cork,
             
+            'Whistles',
+            Design_folk_whistle,
+            Make_whistle,
+            
             'Shawms',
             Design_shawm,
             Design_folk_shawm,
             Make_shawm,
             Make_mouthpiece,
+            Make_bauble,
             
             'Panpipes',        
             Make_panpipe,
