@@ -566,8 +566,13 @@ class Instrument_designer(config.Action_with_output_dir):
         #posscore = 1.0/sum(posscores) if posscores else 1e30
         return negscore
 
+    def patch_instrument(self, inst):
+        """ Hook to modify instrument before scoring. """
+        return inst
     
     def score(self, inst):
+        inst = self.patch_instrument(inst)
+    
         score = 0.0
         div = 0.0
         
@@ -639,18 +644,20 @@ class Instrument_designer(config.Action_with_output_dir):
             else:
                 pickle.dump(self, f)
 
-        self.instrument.prepare()
+        patched_instrument = self.patch_instrument(self.instrument)
+        patched_instrument.prepare()
         
-        any_extra = any( item != 0.0 for item in self.hole_extra_height_by_diameter )
-        if any_extra:
-            mod_instrument = self.unpack( state_vec )
-            #mod_instrument.hole_extra_height_by_diameter = [ 0.0 ] * len(self.hole_extra_height_by_diameter)
-            mod_instrument.hole_lengths = [
-                (mod_instrument.outer(mod_instrument.hole_positions[i])
-                 - mod_instrument.inner(mod_instrument.hole_positions[i])) * 0.5
-                for i in range(self.n_holes)
-            ]
-            mod_instrument.prepare()
+        #any_extra = any( item != 0.0 for item in self.hole_extra_height_by_diameter )
+        #if any_extra:
+        #TODO: implement embextra using patch_instrument
+        mod_instrument = self.unpack( state_vec )
+        #mod_instrument.hole_extra_height_by_diameter = [ 0.0 ] * len(self.hole_extra_height_by_diameter)
+        mod_instrument.hole_lengths = [
+            (mod_instrument.outer(mod_instrument.hole_positions[i])
+             - mod_instrument.inner(mod_instrument.hole_positions[i])) * 0.5
+            for i in range(self.n_holes)
+        ]
+        mod_instrument.prepare()
         
         diagram = svg.SVG()
         
@@ -689,7 +696,7 @@ class Instrument_designer(config.Action_with_output_dir):
         text_y = 0
         for note, fingers in self.fingerings:
             w1 = wavelength(note, self.transpose)
-            w2, grad = self.instrument.true_wavelength_near(w1, fingers, self.max_grad)
+            w2, grad = patched_instrument.true_wavelength_near(w1, fingers, self.max_grad)
             cents = int(round( log2(w2/w1) * 1200.0 ))
 
             n_probes = 301
@@ -698,7 +705,7 @@ class Instrument_designer(config.Action_with_output_dir):
             step = pow(0.5, max_cents/((n_probes-1)*0.5*1200.0))
             low = w1 * pow(step, -(n_probes-1)/2.0)
             probes = [ low * pow(step,i) for i in range(n_probes) ]
-            scores = [ self.instrument.resonance_score(probe, fingers) for probe in probes ]
+            scores = [ patched_instrument.resonance_score(probe, fingers) for probe in probes ]
 
             graph_x = text_x+200
             points = [ (graph_x+i*width/n_probes,text_y-score*7.0)
@@ -713,12 +720,12 @@ class Instrument_designer(config.Action_with_output_dir):
                   '%5s %s %-4d cents grad=%.1f' % (describe(w1), '     ' if cents == 0 else ' flat' if cents > 0 else 'sharp', abs(cents), grad)
             )
             
-            if any_extra:
-                w3, grad3 = mod_instrument.true_wavelength_near(w1, fingers, self.max_grad)
-                cents3 = int(round( log2(w3/w1) * 1200.0 ))
-                diagram.text(graph_x + width, text_y,
-                      '%s %-4d cents grad=%.1f diff=%d' % ('     ' if cents3 == 0 else ' flat' if cents3 > 0 else 'sharp', abs(cents3), grad3, cents3-cents)
-                )
+            #if any_extra:
+            w3, grad3 = mod_instrument.true_wavelength_near(w1, fingers, self.max_grad)
+            cents3 = int(round( log2(w3/w1) * 1200.0 ))
+            diagram.text(graph_x + width, text_y,
+                  '%s %-4d cents grad=%.1f diff=%d' % ('     ' if cents3 == 0 else ' flat' if cents3 > 0 else 'sharp', abs(cents3), grad3, cents3-cents)
+            )
             
             
             text_y -= 25
