@@ -81,7 +81,7 @@ def make_hole(diameter, length):
     return hole
 
 @config.help("""\
-Make a Viking-style panpipe.
+[Experimental] Make a Viking-style panpipe.
 """)
 @config.Float_flag('thickness', 'Instrument thickness.\n(Wood thickness should be half this if milling.)')
 @config.Float_flag('wall', 'Minimum wall thickness')
@@ -119,30 +119,35 @@ class Make_panpipe(make.Make):
         string_hole.rotate(1,0,0, 90)
         
         xlow = xs[0]-zsize
-        xmid = xs[-1]*0.5
+        #xmid = xs[-1]*0.5
         xhigh = xs[-1]+zsize
         
         zhigh = lengths[0]+zsize*0.5
-        zmid  = max(lengths[-1]+zsize*0.5, zhigh-(xhigh-xmid))
+        #zmid  = max(lengths[-1]+zsize*0.5, zhigh-(xhigh-xmid))
         
-        string_x = (xmid+xhigh)*0.5 - diameter
-        string_z = (zmid+zhigh)*0.5 - diameter
+        trim = min(xhigh-xlow,zhigh) * 0.5
+        
+        #string_x = (xmid+xhigh)*0.5 - diameter
+        #string_z = (zmid+zhigh)*0.5 - diameter
         #string_z = lengths[3] + diameter*2
+        string_x = xhigh-trim*0.5-diameter
+        string_z = zhigh-trim*0.5-diameter
+        
         string_hole.move(string_x,0,string_z)
         
         loop = shape.Loop([
             (xlow,0),
             (xhigh,0),
-            (xhigh,zmid),
-            (xmid,zhigh),
+            (xhigh,zhigh-trim),
+            (xhigh-trim,zhigh),
             (xlow,zhigh)
         ])
 
         loop_bevel = shape.Loop([
             (xlow,pad),
             (xhigh,pad),
-            (xhigh,zmid),
-            (xmid,zhigh),
+            (xhigh,zhigh-trim),
+            (xhigh-trim,zhigh),
             (xlow,zhigh)
         ])
         
