@@ -1,7 +1,7 @@
 
 import math, traceback, os, random, sys, io, collections
 
-import profile, design, pack
+from . import profile, design, pack, geom
 
 from nesoni import config
 
@@ -81,6 +81,12 @@ class Loop(list):
             sum_y += (last[1]+point[1])*val
             last = point
         div *= 3.0
+        
+        if not div: # Probably a point, possibly a line, do something vaguely sensible
+           div = len(self)
+           sum_x = sum(point[0] for point in self)
+           sum_y = sum(point[1] for point in self)
+        
         return (sum_x/div, sum_y/div)
     
     def scale(self, factor):
@@ -101,6 +107,12 @@ class Loop(list):
     def offset(self, dx,dy):
         return Loop( (x+dx,y+dy) for x,y in self )
 
+    def flip_x(self):
+        return Loop( (-x,y) for x,y in self[::-1] )
+        
+    def flip_y(self):
+        return Loop( (x,-y) for x,y in self[::-1] )
+
     def mask(self, res):
         import mask
         lines = [ (self[i][0]*res,self[i][1]*res,
@@ -168,6 +180,32 @@ def squared_circle(xpad,ypad, diameter=1.0):
     
     return Loop(result)
 
+def rounded_rectangle(x0,x1,y0,y1, diameter):    
+    radius = min(diameter,x1-x0,y1-y0)*0.5 
+    result = [ ]
+    for i in range(QUALITY):
+        a = (i+0.5)*math.pi*2.0/QUALITY
+        x = math.cos(a)*radius
+        if x < 0: x += x0+radius
+        else: x += x1-radius
+        y = math.sin(a)*radius
+        if y < 0: y += y0+radius
+        else: y += y1-radius
+        result.append( (x,y) )
+    return Loop(result)
+
+def halfrounded_rectangle(x0,x1,y0,y1):
+    radius = x1-x0
+    result = [ ]
+    for i in range(QUALITY):
+        a = ((i+0.5)/QUALITY-0.5)*math.pi
+        x = math.cos(a)*radius + x0
+        y = math.sin(a)*radius
+        if y < 0: y += y0+radius
+        else: y += y1-radius
+        result.append( (x,y) )
+    result.extend([ (x0,y1), (x0,y0) ])
+    return Loop(result)
 
 def lens(amount, circumpherence=math.pi):
     result = [ ]
@@ -315,7 +353,7 @@ def extrude_profile(*profiles, **kwargs):
             zs.append(z)
             shapes.append(cross_section(*lows))
         if not i or (i < len(pos)-1 and lows != highs):
-            zs.append(z)
+            zs.append(z)            
             shapes.append(cross_section(*highs))
     
     return extrusion(zs, shapes, name=name)
@@ -505,3 +543,92 @@ def make_formwork(outer, bore, length, top_fractions, bottom_fractions,
     return lower, upper
 
 
+
+
+def frame_extrusion(frames, shapes):
+    nframes = len(frames)
+    nshape = len(shapes[0])
+    
+    verts = [ ]
+    for i,frame in enumerate(frames):
+        for x,y in shapes[i]:
+            verts.append( frame.apply(geom.XYZ(x,y,0.0)) )
+    
+    end0 = len(verts)
+    verts.append( frames[0].apply(geom.XYZ(*shapes[0].centroid + (0.0,))) )
+    end1 = len(verts)
+    verts.append( frames[-1].apply(geom.XYZ(*shapes[-1].centroid + (0.0,))) )
+        
+    faces = [ ]
+    for i in range(nframes-1):
+        for j in range(nshape):
+            #faces.append( ( 
+            #    (i+1)*nshape+j, i*nshape+j,
+            #    i*nshape+(j+1)%nshape, (i+1)*nshape+(j+1)%nshape 
+            #    ) )
+            faces.append( ( 
+                (i+1)*nshape+j, i*nshape+j,
+                i*nshape+(j+1)%nshape, 
+                ) )
+            faces.append( ( 
+                (i+1)*nshape+j,
+                i*nshape+(j+1)%nshape, (i+1)*nshape+(j+1)%nshape 
+                ) )
+
+    for i in range(nshape):
+        i1 = (i+1)%nshape
+        faces.append( (i1,i,end0) )
+        faces.append( (i+nshape*(nframes-1),i1+nshape*(nframes-1),end1) )
+
+    return create(verts, faces)
+
+
+def path_extrusion(path, cross_section, *profiles):
+    poses = set()
+    for item in profiles:
+        poses.update(item.pos)
+    poses = sorted(poses)
+    
+    i = 0
+    while i < len(poses)-1:
+        #print poses[i+1], poses[i]
+        #ratio = (path.get_point(poses[i+1])-path.get_point(poses[i])).mag() / abs(poses[i+1]-poses[i])
+        #print 'r',ratio
+        #if abs(poses[i+1]-poses[i]) > 1.0 and ratio < 1.0:
+        b = path.get_bentness(poses[i],poses[i+1])
+        print 'b', b
+        if b > 1.0/QUALITY:
+            poses.insert(i+1, (poses[i]+poses[i+1])*0.5)
+        else:
+            i += 1
+    
+    print poses
+    
+    frames = [ ]
+    shapes = [ ]
+    
+    for i,pos in enumerate(poses):
+        lows = [ item(pos) for item in profiles ]
+        highs = [ item(pos,True) for item in profiles ]
+    
+        if i:
+            frames.append(path.get_frame(pos))
+            shapes.append(cross_section(*lows))
+        if not i or (i < len(poses)-1 and lows != highs):
+            frames.append(path.get_frame(pos))            
+            shapes.append(cross_section(*highs))
+    
+    return frame_extrusion(frames, shapes)
+
+
+
+
+
+
+
+
+
+
+
+
+
