@@ -16,28 +16,40 @@ def sketch(thing, outname):
     print outname,
     sys.stdout.flush()
     
-    def iterator():
-        yield thing, 1
-        
-        item_rot = thing.copy()
-        item_rot.rotate(1,0,0,-90)
-        yield item_rot, 1
-        del item_rot
-        
-        item_iso = thing.copy()
-        item_iso.rotate(0,0,1,-45, 256)
-        item_iso.rotate(1,0,0,-45, 256)
-        yield item_iso, 0
-        del item_iso
-    
     ox = 0
     oy = 0
     
     pic = svg.SVG()
     pic.require(0,0)
+    
+    triangles = thing.triangles()
+    
+    def rot(triangles, x,y,z,angle):
+        mat = shape.rotation_matrix(x,y,z,angle)
+        return [ [ shape.transform_point_3(mat,item2) for item2 in item ] for item in triangles ]
+
+    def iterator():
+        #yield thing, 1
+        yield triangles, 1
         
-    for (item,showdim) in iterator():
-        extent = item.extent()
+        #item_rot = thing.copy()
+        #item_rot.rotate(1,0,0,-90)
+        #yield item_rot, 1
+        #del item_rot
+        yield rot(triangles, 1,0,0,-90), 1
+        
+        #item_iso = thing.copy()
+        #item_iso.rotate(0,0,1,-45, 256)
+        #item_iso.rotate(1,0,0,-45, 256)
+        #yield item_iso, 0
+        #del item_iso        
+        yield rot(rot(triangles, 0,0,1,-45), 1,0,0,-45), 0
+    
+        
+#    for (item,showdim) in iterator():
+#        extent = item.extent()
+    for (this_triangles,showdim) in iterator():
+        extent = shape.extent_3(item2 for item in this_triangles for item2 in item)
         
         if extent.xmax-extent.xmin < extent.ymax-extent.ymin:
             ox = pic.max_x + 10
@@ -57,7 +69,7 @@ def sketch(thing, outname):
             pic.text(ox+extent.xmax + 5, -oy-ymid, '%.1fmm' % (extent.ymax-extent.ymin))    
         
         lines = collections.defaultdict(list)
-        for tri in item.triangles():
+        for tri in this_triangles:
             #a = numpy.array(tri)
             #normal = numpy.cross(a[1]-a[0],a[2]-a[0])
             normal = cross(sub(tri[1],tri[0]),sub(tri[2],tri[0]))
